==> facebook-nodejs-business-sdk-4.0.8.tgz: package/docs/EXTENDED_CREDIT_LINE_OWNING_CREDIT_ALLOCATION_CONFIGS_CREATE.js <==
/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * @flow
 */

const bizSdk = require('facebook-nodejs-business-sdk');
const process = require('process');
const ExtendedCredit = bizSdk.ExtendedCredit;
const ExtendedCreditAllocationConfig = bizSdk.ExtendedCreditAllocationConfig;
const AbstractObject = bizSdk.AbstractObject;

let app_id = '1224202007596125';
let access_token = 'EAARZAZA73LzF0BACZADSZCYwMsLHUTwAAYKm5Tciz5GZCGM8ZAtqoM12q8ybFt6dpElSqbUuXm77dGmZAeK6r1wygAQZCslDqpsVQY6RQA3WhLirP8BcgoKoCTvlyKzkx6xGPZCcRiDXUleDqSbnAQBd5k0ZBhuLf1AB2VsIS5OlYDoTQlOoRuVpmZAiJY9O6d688sZD';
let app_secret = '709348c9665c33a4f988ff3950098131';
let partner_access_token = 'EAACovfpTQbcBABTpQadL2itCDWd4f3gZCZBIqdIweJZCXteBs7FZArku6pYNR3aiQHjs4ZCyE7sF8V29tMY7uJYIwvJKcQmfSF2AQbHshvlM4PaVZBexeDXv3ZAn1zBrajwaoV5yEy9VK2soWl52t45Oda1jygia4G4cAbASH7OZAFYZCC1RZC5eM0PF4CzIj3LikQSZA7K5ZCrEkAZDZD';
let extended_credit_line_id = '379182178863816';
let child_business_id = '91030447373044';
const api = bizSdk.FacebookAdsApi.init(
  partner_access_token
);
const showDebugingInfo = true; // Setting this to true shows more debugging info.
if (showDebugingInfo) {
  api.setDebug(true);
}

const logApiCallResult = (apiCallName, data) => {
  console.log(apiCallName);
  if (showDebugingInfo) {
    console.log('Data:' + JSON.stringify(data));
  }
};
let fields, params;
void async function() {
try {
//  _DOC oncall [business_api]
//  _DOC open [EXTENDED_CREDIT_LINE_OWNING_CREDIT_ALLOCATION_CONFIGS_CREATE]
//  _DOC vars [partner_access_token]
//  _DOC vars [child_business_id]
//  _DOC vars [extended_credit_line_id]
fields = [
];
params = {
  'receiving_business_id' : child_business_id,
  'amount' : '15',
};
let credit_line = await (new ExtendedCredit(extended_credit_line_id)).createOwningCreditAllocationConfig(
  fields,
  params
);
let credit_line_id = credit_line.id;

fields = [
];
params = {
};
await (new ExtendedCreditAllocationConfig(credit_line_id)).delete(
  params
);

//  _DOC close [EXTENDED_CREDIT_LINE_OWNING_CREDIT_ALLOCATION_CONFIGS_CREATE]
}
catch(error) {
  console.log(error);
  process.exit(1);
}
}();

==> facebook-nodejs-business-sdk-6.0.0.tgz: package/docs/EXTENDED_CREDIT_LINE_OWNING_CREDIT_ALLOCATION_CONFIGS_CREATE.js <==
/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * @flow
 */

const bizSdk = require('facebook-nodejs-business-sdk');
const process = require('process');
const ExtendedCredit = bizSdk.ExtendedCredit;
const ExtendedCreditAllocationConfig = bizSdk.ExtendedCreditAllocationConfig;
const AbstractObject = bizSdk.AbstractObject;

let app_id = '1224202007596125';
let access_token = 'EAARZAZA73LzF0BACZADSZCYwMsLHUTwAAYKm5Tciz5GZCGM8ZAtqoM12q8ybFt6dpElSqbUuXm77dGmZAeK6r1wygAQZCslDqpsVQY6RQA3WhLirP8BcgoKoCTvlyKzkx6xGPZCcRiDXUleDqSbnAQBd5k0ZBhuLf1AB2VsIS5OlYDoTQlOoRuVpmZAiJY9O6d688sZD';
let app_secret = '709348c9665c33a4f988ff3950098131';
let partner_access_token = 'EAACovfpTQbcBABTpQadL2itCDWd4f3gZCZBIqdIweJZCXteBs7FZArku6pYNR3aiQHjs4ZCyE7sF8V29tMY7uJYIwvJKcQmfSF2AQbHshvlM4PaVZBexeDXv3ZAn1zBrajwaoV5yEy9VK2soWl52t45Oda1jygia4G4cAbASH7OZAFYZCC1RZC5eM0PF4CzIj3LikQSZA7K5ZCrEkAZDZD';
let extended_credit_line_id = '379182178863816';
let child_business_id = '91030447373044';
const api = bizSdk.FacebookAdsApi.init(
  partner_access_token,
  crash_log=false
);
const showDebugingInfo = true; // Setting this to true shows more debugging info.
if (showDebugingInfo) {
  api.setDebug(true);
}

const logApiCallResult = (apiCallName, data) => {
  console.log(apiCallName);
  if (showDebugingInfo) {
    console.log('Data:' + JSON.stringify(data));
  }
};
let fields, params;
void async function() {
try {
//  _DOC oncall [business_api]
//  _DOC open [EXTENDED_CREDIT_LINE_OWNING_CREDIT_ALLOCATION_CONFIGS_CREATE]
//  _DOC vars [partner_access_token]
//  _DOC vars [child_business_id]
//  _DOC vars [extended_credit_line_id]
fields = [
];
params = {
  'receiving_business_id' : child_business_id,
  'amount' : '15',
};
let credit_line = await (new ExtendedCredit(extended_credit_line_id)).createOwningCreditAllocationConfig(
  fields,
  params
);
let credit_line_id = credit_line.id;

fields = [
];
params = {
};
await (new ExtendedCreditAllocationConfig(credit_line_id)).delete(
  params
);

//  _DOC close [EXTENDED_CREDIT_LINE_OWNING_CREDIT_ALLOCATION_CONFIGS_CREATE]
}
catch(error) {
  console.log(error);
  process.exit(1);
}
}();
